@@ -8,7 +8,10 @@ from typing import Literal, Tuple
 
 class Cli:
     def __init__(self):
-        ...
+        self._config = {
+            "server": "http://127.0.0.1:8000",
+            "croc_relay": "142.171.214.153:27011"
+        }
 
     def deduplicate(self, in_file: str, out_file: str, target_col='data', chunk_size = 200, threshold=None, method:Literal["edit", "rouge", "bleu"]='edit', use_jieba=False):
         if method == "edit":
@@ -31,6 +34,35 @@ class Cli:
         simi.load_data(in_file, target_col=target_col)
         simi.deduplicate(chunk_size=chunk_size, save_to_file=out_file, threshold=threshold)
 
+    @staticmethod
+    def prev(extract_dir):
+        from .parser.code.code import extract_to_md
+        extract_to_md(extract_dir)
+
+    def send(self, files_or_folder: str, **kwargs):
+        command = f"croc  --relay {self._config['croc_relay']} send {files_or_folder} " + " ".join([f"--{k} {v}" for k, v in kwargs.items()])
+        os.system(command)
+    def send2(self, filename: str, space: str):
+        from flaxkv import FlaxKV
+        db = FlaxKV(db_name=space, root_path_or_url=self._config['server'], show_progress=True)
+        with open(filename, 'rb') as f:
+            content = f.read()
+            db[filename] = content
+            db.write_immediately(write=True)
+            # 流式读取
+            # while True:
+            #     data = f.read(1024)
+            #     if not data:
+            #         break
+
+    def recv2(self,filename: str, space: str):
+        from flaxkv import FlaxKV
+        db = FlaxKV(db_name=space, root_path_or_url=self._config['server'], show_progress=True)
+        content = db[filename]
+        with open(filename, 'wb') as f:
+            f.write(content)
+        db.buffer_dict.clear()
+
     @staticmethod
     def post(url: str, data: dict, concurrent: int = 10, ):
         import asyncio
